pub enum FacadeChunkEliminationReason {
EmittedChunkMergedIntoManualGroup,
DynamicEntryMergedIntoManualGroup,
DynamicEntryMergedIntoUserDefinedEntry,
DynamicEntryMergedIntoCommonChunk,
CommonChunkMergedIntoFacadeUserDefinedEntry,
}Expand description
The specific optimization scenario that led to a facade chunk being eliminated.
Variants
EmittedChunkMergedIntoManualGroup
Emitted chunk (AllowExtension) merged into manual code splitting group. Export name conflicts are checked before merging.
DynamicEntryMergedIntoManualGroup
Dynamic entry chunk merged into manual code splitting group.
DynamicEntryMergedIntoUserDefinedEntry
Dynamic entry chunk merged into user-defined entry chunk.
DynamicEntryMergedIntoCommonChunk
Dynamic entry chunk merged into common chunk.
CommonChunkMergedIntoFacadeUserDefinedEntry
Common chunk merged into facade user-defined entry chunk.