pub enum PostChunkOptimizationOperation {
Removed,
RemovedWithPreservedExports,
}Expand description
Tracks post-optimization operations applied to chunks during code splitting. A chunk present in the map has been removed and merged into another chunk.
Variants
Removed
The chunk has been removed and merged into another chunk. e.g., a dynamic chunk merged into a common chunk or user-defined entry chunk.
RemovedWithPreservedExports
The chunk has been removed, but its exports should be preserved in the target chunk.
e.g., an emitted chunk with preserveEntrySignatures: 'allow-extension' merged into
a manual chunks group - all exports should be preserved even though the original
emitted chunk is removed.