Chunk

Struct Chunk 

pub struct Chunk {
Show 33 fields pub exec_order: u32, pub kind: ChunkKind, pub modules: Vec<ModuleIdx>, pub name: Option<ArcStr>, pub file_name: Option<ArcStr>, pub pre_rendered_chunk: Option<RollupPreRenderedChunk>, pub preliminary_filename: Option<PreliminaryFilename>, pub preliminary_sourcemap_filename: Option<PreliminaryFilename>, pub absolute_preliminary_filename: Option<String>, pub canonical_names: FxHashMap<SymbolRef, CompactStr>, pub node_mode_external_ns_names: FxHashMap<SymbolRef, CompactStr>, pub cross_chunk_imports: Vec<ChunkIdx>, pub cross_chunk_dynamic_imports: Vec<ChunkIdx>, pub dynamic_imports_from_external_modules: Vec<ModuleIdx>, pub bits: BitSet, pub imports_from_other_chunks: FxIndexMap<ChunkIdx, Vec<CrossChunkImportItem>>, pub require_binding_names_for_other_chunks: FxHashMap<ChunkIdx, String>, pub direct_imports_from_external_modules: Vec<(ModuleIdx, Vec<(ModuleIdx, NamedImport)>)>, pub import_symbol_from_external_modules: FxIndexSet<ModuleIdx>, pub exports_to_other_chunks: FxHashMap<SymbolRef, Vec<CompactStr>>, pub input_base: ArcStr, pub debug_info: Vec<ChunkDebugInfo>, pub chunk_reason_type: Box<ChunkReasonType>, pub preserve_entry_signature: Option<PreserveEntrySignatures>, pub depended_runtime_helper: RuntimeHelper, pub entry_level_external_module_idx: Vec<ModuleIdx>, pub insert_map: FxHashMap<ModuleIdx, Vec<(ModuleIdx, ImportRecordIdx)>>, pub remove_map: FxHashMap<ModuleIdx, Vec<ImportRecordIdx>>, pub transformed_parts_rendered: FxIndexMap<(ModuleIdx, ImportRecordIdx), String>, pub module_groups: Vec<ModuleGroup>, pub module_idx_to_group_idx: FxHashMap<ModuleIdx, usize>, pub module_idx_to_render_concatenated_module: FxHashMap<ModuleIdx, RenderedConcatenatedModuleParts>, pub output_exports: OutputExports,
}

Fields

exec_order: u32kind: ChunkKindmodules: Vec<ModuleIdx>name: Option<ArcStr>file_name: Option<ArcStr>pre_rendered_chunk: Option<RollupPreRenderedChunk>preliminary_filename: Option<PreliminaryFilename>preliminary_sourcemap_filename: Option<PreliminaryFilename>absolute_preliminary_filename: Option<String>canonical_names: FxHashMap<SymbolRef, CompactStr>node_mode_external_ns_names: FxHashMap<SymbolRef, CompactStr>

For mixed-mode externals: maps external namespace_ref to the node-mode binding name. Only populated when an external has both ESM and non-ESM importers needing interop.

cross_chunk_imports: Vec<ChunkIdx>cross_chunk_dynamic_imports: Vec<ChunkIdx>dynamic_imports_from_external_modules: Vec<ModuleIdx>bits: BitSetimports_from_other_chunks: FxIndexMap<ChunkIdx, Vec<CrossChunkImportItem>>require_binding_names_for_other_chunks: FxHashMap<ChunkIdx, String>direct_imports_from_external_modules: Vec<(ModuleIdx, Vec<(ModuleIdx, NamedImport)>)>

The first element of tuple is module idx of external module the second element is the related named import of external module. The second ModuleIdx is the importer of the named import which is used to look up related import attribute.

import_symbol_from_external_modules: FxIndexSet<ModuleIdx>

Used for cjs, umd, iife The module directly imported symbol actually came from external modules.

exports_to_other_chunks: FxHashMap<SymbolRef, Vec<CompactStr>>input_base: ArcStrdebug_info: Vec<ChunkDebugInfo>chunk_reason_type: Box<ChunkReasonType>preserve_entry_signature: Option<PreserveEntrySignatures>depended_runtime_helper: RuntimeHelperentry_level_external_module_idx: Vec<ModuleIdx>insert_map: FxHashMap<ModuleIdx, Vec<(ModuleIdx, ImportRecordIdx)>>remove_map: FxHashMap<ModuleIdx, Vec<ImportRecordIdx>>transformed_parts_rendered: FxIndexMap<(ModuleIdx, ImportRecordIdx), String>module_groups: Vec<ModuleGroup>module_idx_to_group_idx: FxHashMap<ModuleIdx, usize>module_idx_to_render_concatenated_module: FxHashMap<ModuleIdx, RenderedConcatenatedModuleParts>output_exports: OutputExports

Pre-computed export mode for the chunk

Implementations

Source

impl Chunk

pub fn new( name: Option<ArcStr>, file_name: Option<ArcStr>, bits: BitSet, modules: Vec<ModuleIdx>, kind: ChunkKind, input_base: ArcStr, preserve_entry_signature: Option<PreserveEntrySignatures>, ) -> Self

pub fn has_side_effect(&self, module_table: &ModuleTable) -> bool

pub fn import_path_for(&self, importee: &Chunk) -> String

pub fn relative_path_for(&self, target: &Path) -> String

pub async fn filename_template( &self, options: &NormalizedBundlerOptions, rollup_pre_rendered_chunk: &RollupPreRenderedChunk, ) -> Result<FilenameTemplate>

pub async fn generate_preliminary_filename( &self, options: &NormalizedBundlerOptions, rollup_pre_rendered_chunk: &RollupPreRenderedChunk, chunk_name: &ArcStr, hash_placeholder_generator: &mut HashPlaceholderGenerator, used_name_counts: &FxDashMap<ArcStr, u32>, ) -> Result<PreliminaryFilename>

pub async fn generate_preliminary_sourcemap_filename( &self, options: &NormalizedBundlerOptions, rollup_pre_rendered_chunk: &RollupPreRenderedChunk, chunk_name: &ArcStr, hash_placeholder_generator: &mut HashPlaceholderGenerator, used_name_counts: &FxDashMap<ArcStr, u32>, ) -> Result<Option<PreliminaryFilename>>

pub fn user_defined_entry_module_idx(&self) -> Option<ModuleIdx>

pub fn user_defined_entry_module<'module>( &self, module_table: &'module ModuleTable, ) -> Option<&'module NormalModule>

pub fn entry_module_idx(&self) -> Option<ModuleIdx>

pub fn entry_module<'module>( &self, module_table: &'module ModuleTable, ) -> Option<&'module NormalModule>

pub fn is_user_defined_entry(&self) -> bool

pub fn is_async_entry(&self) -> bool

pub fn is_entry_point(&self) -> bool

Returns true if this chunk is an entry point. Entry points include both user-defined entries and dynamically imported modules. When generatedCode.symbols is enabled, entry point chunks get Symbol.toStringTag defined.