pub struct SymbolRefDb { /* private fields */ }Implementations
Sourceimpl SymbolRefDb
impl SymbolRefDb
pub fn new() -> Self
pub fn with_inner( self, inner: IndexVec<ModuleIdx, Option<SymbolRefDbForModule>>, ) -> Self
Sourcepub fn is_facade_symbol(&self, refer: SymbolRef) -> bool
pub fn is_facade_symbol(&self, refer: SymbolRef) -> bool
The facade means the symbol does not actually exist in the original AST.
Panics
- If the module does not exist in the symbol database.
Sourcepub fn clone_without_scoping(&self) -> SymbolRefDb
pub fn clone_without_scoping(&self) -> SymbolRefDb
Clone the symbol ref DB for caching, using an empty Scoping to avoid
expensive cloning. After each build, merge_from_build restores the
authoritative Scoping and extends classic_data for facade symbols.
Sourceimpl SymbolRefDb
impl SymbolRefDb
pub fn into_inner(self) -> IndexVec<ModuleIdx, Option<SymbolRefDbForModule>>
pub fn inner(&self) -> &IndexVec<ModuleIdx, Option<SymbolRefDbForModule>>
pub fn store_local_db( &mut self, module_idx: ModuleIdx, local_db: SymbolRefDbForModule, )
Sourcepub fn has_module_preserve_jsx(&self) -> bool
pub fn has_module_preserve_jsx(&self) -> bool
Returns whether any module uses JSX preserve mode.
Sourcepub fn set_has_module_preserve_jsx(&mut self)
pub fn set_has_module_preserve_jsx(&mut self)
Mark that at least one module uses JSX preserve mode.
This is used as a fast-path optimization in link().
pub fn create_facade_root_symbol_ref( &mut self, owner: ModuleIdx, name: &str, ) -> SymbolRef
pub fn canonical_name_for<'name>( &self, refer: SymbolRef, canonical_names: &'name FxHashMap<SymbolRef, CompactStr>, ) -> Option<&'name CompactStr>
Sourcepub fn canonical_name_for_or_original<'a>(
&'a self,
refer: SymbolRef,
canonical_names: &'a FxHashMap<SymbolRef, CompactStr>,
) -> &'a str
pub fn canonical_name_for_or_original<'a>( &'a self, refer: SymbolRef, canonical_names: &'a FxHashMap<SymbolRef, CompactStr>, ) -> &'a str
Get the canonical name for a symbol, falling back to the original name if not renamed. This is more efficient than storing original names in canonical_names map.
Sourcepub fn original_name(&self, canonical_ref: SymbolRef) -> CompactStr
pub fn original_name(&self, canonical_ref: SymbolRef) -> CompactStr
The owned pre-deconfliction name for an already-canonical symbol: its name,
but with the first character upper-cased when module.preserve_jsx is enabled
and the symbol is a JSX component binding that must start with a capital letter
(e.g. foo -> Foo). This is the base name the renamer feeds into conflict
resolution.
pub fn get(&self, refer: SymbolRef) -> &SymbolRefDataClassic
pub fn get_mut(&mut self, refer: SymbolRef) -> &mut SymbolRefDataClassic
Sourcepub fn find_mut(&mut self, target: SymbolRef) -> SymbolRef
pub fn find_mut(&mut self, target: SymbolRef) -> SymbolRef
https://en.wikipedia.org/wiki/Disjoint-set_data_structure See Path halving
pub fn canonical_ref_for(&self, target: SymbolRef) -> SymbolRef
Sourcepub fn canonical_ref_resolving_namespace(
&self,
symbol_ref: SymbolRef,
) -> SymbolRef
pub fn canonical_ref_resolving_namespace( &self, symbol_ref: SymbolRef, ) -> SymbolRef
Resolves a symbol reference to its canonical form, following namespace aliases.
pub fn is_declared_in_root_scope(&self, refer: SymbolRef) -> bool
Sourcepub fn get_create_reason(&self, symbol_ref: &SymbolRef) -> &str
pub fn get_create_reason(&self, symbol_ref: &SymbolRef) -> &str
If it is not a facade symbol, No create reason found will be returned.